estSurvCens: Survival Function Of Censoring Process

View source: R/DiscSurvEstimation.R

estSurvCensR Documentation

Survival Function Of Censoring Process

Description

Estimates the marginal survival function G(T=t) of the censoring process based on a life table estimator. Compatible with single event and competing risks data.

Usage

estSurvCens(dataShort, timeColumn, eventColumns, censInterval = "middle")

Arguments

dataShort

Data in original short format (class "data.frame").

timeColumn

Name of column with discrete time intervals (class "character").

eventColumns

Names of the event columns of dataShort (class "character"). In the competing risks case the event columns have to be in dummy encoding format (class "numeric").

censInterval

Assumption about when censoring takes places within an interval on the continuous time scale (class "character"). Possible values are "start", "middle", "end". Default is "middle".

Value

Named vector of estimated survival function of the censoring process for all time points except the last theoretical interval.

Note

In the censoring survival function the last time interval \left[ a_q, \infty \right) has the probability of zero.

Author(s)

Thomas Welchowski t.welchowski@psychologie.uzh.ch

References

\insertRef

tutzModelDiscdiscSurv

See Also

estSurv

Examples


# Load unemployment data
library(Ecdat)
data(UnempDur)

# Select subsample
subUnempDur <- UnempDur [1:100, ]

######################
# Single event example

# Estimate censoring survival function G(t)
estG <- estSurvCens(dataShort = subUnempDur, timeColumn = "spell", 
eventColumns = "censor1")
estG

#########################
# Competing risks example

# Estimate censoring survival function G(t)
estG <- estSurvCens(dataShort = subUnempDur, timeColumn = "spell", 
eventColumns = c("censor1", "censor2", "censor3", "censor4"))
estG



discSurv documentation built on April 29, 2026, 9:07 a.m.