martingaleResid: Martingale Residuals

martingaleResidR Documentation

Martingale Residuals

Description

Estimates the martingale residuals of discrete survival model.

Usage

martingaleResid(hazards, dataLong, storeAugData = TRUE)

## S3 method for class 'discSurvMartingaleResid'
plot(x, covariates, ...)

Arguments

hazards

Predicted hazards from a discrete survival model (class "numeric").

dataLong

Data set in long format (class "data.frame").

storeAugData

Should the augmented data set be saved (class "logical")? Defaults is TRUE. The data set is available as attribute "augData".

x

Object of class "discSurvMartingaleResid"

covariates

Names of covariates to plot (class "character").

...

Specification of additional arguments in function plot.

Details

Gives a different plot of each marginal covariate against the martingale residuals. Additionally a nonparametric loess estimation is done.

Value

Martingale residuals for each observation in long format (class "numeric").

Author(s)

Thomas Welchowski t.welchowski@psychologie.uzh.ch

References

\insertRef

tutzModelDiscdiscSurv

\insertReftherneauMartdiscSurv

See Also

glm

Examples


# Example with cross validation and unemployment data 
library(Ecdat)
data(UnempDur)
summary(UnempDur$spell)

# Extract subset of data
set.seed(635)
IDsample <- sample(1:dim(UnempDur)[1], 100)
UnempDurSubset <- UnempDur [IDsample, ]

# Conversion to long format
UnempDurSubsetLong <- dataLong(dataShort = UnempDurSubset,
timeColumn = "spell", eventColumn = "censor1")

# Estimate discrete survival continuation ratio model
contModel <- glm(y ~ timeInt + age + logwage, data = UnempDurSubsetLong,
family = binomial(link = "logit"))

# Fit hazards to the data set in long format
hazPreds <- predict(contModel, type = "response")

# Calculate martingale residuals for the unemployment data subset
MartResid <- martingaleResid (hazards = hazPreds, dataLong = UnempDurSubsetLong)
MartResid
sum(MartResid)

# Plot martingale residuals vs each covariate in the event interval
# Dotted line represents the loess estimate
plot(MartResid, covariates = c("age", "logwage"), dataLong = UnempDurSubsetLong)


discSurv documentation built on April 29, 2026, 9:07 a.m.