| discSurv-package | R Documentation |
Includes functions for data transformations, estimation, evaluation and
simulation of discrete survival analysis. Some important functions are
listed below:
Data preprocessing
dataLong: Transform data from short format into long
format for discrete survival analysis and right censoring.
dataLongCompRisks: Transforms short data format to long
format for discrete survival modelling in the case of competing risks with
right censoring.
Model fitting
estReg: Wrapper to estimate parametric discrete survival models.
estRegSmooth: Wrapper to estimate discrete
semiparametric survival generalized additive models.
estForestCompRisks: Wrapper to estimate discrete survival
random survival forests.
estRecal: Fits a logistic recalibration model to independent test data.
Model evaluation
cIndex: Calculates the concordance index for discrete survival
models, which is an aggregated discrimination measure that integrates out time.
intPredErr: Estimates the integrated prediction error of
discrete survival models.
Post-processing
minNodePruning: Tunes the minimal node side of discrete
survival trees by cross validation.
survTreeLaplaceHazard: Laplace-smothing for discrete hazards,
that were estimated by a survival tree from class "rpart" or "ranger".
"DataShort" format is defined as data without repeated measurements. "DataSemiLong" format consists of repeated measurements, but there are gaps between the discrete time intervals. "DataLong" format is expanded to include all time intervals up to the last observation per individual.
| Package: | discSurv |
| Type: | Package |
| Version: | 2.5.1 |
| Date: | 2026-04-28 |
| License: | GPL-3 |
Thomas Welchowski t.welchowski@psychologie.uzh.ch
Moritz Berger moritz.berger@zi-mannheim.de
David Koehler koehler@imbie.uni-bonn.de
Matthias Schmid matthias.schmid@imbie.uni-bonn.de
bergerTutorialdiscSurv
\insertReftutzModelDiscdiscSurv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.